@@ -2,7 +2,7 @@ use strict;
 use warnings;
 use 5.014;
 
-package Dist::Zilla::Plugin::InsertExample 0.08 {
+package Dist::Zilla::Plugin::InsertExample 0.09 {
 
   use Moose;
   use List::Util qw( first );
@@ -16,6 +16,7 @@ package Dist::Zilla::Plugin::InsertExample 0.08 {
   };
 
   has remove_boiler => (is => 'ro', isa => 'Int');
+  has indent        => (is => 'ro', isa => 'Int', default => 1);
 
   sub munge_files
   {
@@ -52,6 +53,8 @@ package Dist::Zilla::Plugin::InsertExample 0.08 {
       $fh = $file->openr;  
     }
 
+    my $indent = ' ' x $self->indent;
+
     while(<$fh>)
     {
       if($self->remove_boiler)
@@ -62,7 +65,7 @@ package Dist::Zilla::Plugin::InsertExample 0.08 {
         next if /^use warnings;$/;
         return '' if eof $fh;
       }
-      return join "\n", map { " $_" } split /\n/, $_ . do { local $/; my $rest = <$fh>; defined $rest ? $rest : '' };
+      return join "\n", map { "$indent$_" } split /\n/, $_ . do { local $/; my $rest = <$fh>; defined $rest ? $rest : '' };
     }
 
   }
@@ -84,7 +87,7 @@ Dist::Zilla::Plugin::InsertExample - Insert example into your POD from a file
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -142,6 +145,14 @@ source root.
 Remove the C<#!/usr/bin/perl>, C<use strict;> or C<use warnings;> from
 the beginning of your example before inserting them into the POD.
 
+=head2 indent
+
+Specifies the number of spaces to indent by.  This is 1 by default,
+because it is sufficient to force POD to consider it a verbatim
+paragraph.  I understand a lot of Perl programmers out there prefer
+4 spaces.  You can also set this to 0 to get no indentation at all
+and it won't be a verbatim paragraph at all.
+
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
